==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate.md <==
# AmazonAuroraAmazonAuroraInstanceAlternate


```text
aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate
```

```text
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')
```



| Illustration | AmazonAuroraAmazonAuroraInstanceAlternate | AmazonAuroraAmazonAuroraInstanceAlternateCard | AmazonAuroraAmazonAuroraInstanceAlternateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate.png) | ![illustration for AmazonAuroraAmazonAuroraInstanceAlternate](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate.Local.png) | ![illustration for AmazonAuroraAmazonAuroraInstanceAlternateCard](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternateCard.Local.png) | ![illustration for AmazonAuroraAmazonAuroraInstanceAlternateGroup](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternateGroup.Local.png) |




## AmazonAuroraAmazonAuroraInstanceAlternate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonAuroraInstanceAlternate
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')

' renders the element
AmazonAuroraAmazonAuroraInstanceAlternate('AmazonAuroraAmazonAuroraInstanceAlternate', 'Amazon Aurora Amazon Aurora Instance Alternate', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonAuroraInstanceAlternate
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')

' renders the element
AmazonAuroraAmazonAuroraInstanceAlternate('AmazonAuroraAmazonAuroraInstanceAlternate', 'Amazon Aurora Amazon Aurora Instance Alternate', 'an optional tech label')
@enduml
```

## AmazonAuroraAmazonAuroraInstanceAlternateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonAuroraInstanceAlternateCard
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')

' renders the element
AmazonAuroraAmazonAuroraInstanceAlternateCard('AmazonAuroraAmazonAuroraInstanceAlternateCard', 'Amazon Aurora Amazon Aurora Instance Alternate Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonAuroraInstanceAlternateCard
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')

' renders the element
AmazonAuroraAmazonAuroraInstanceAlternateCard('AmazonAuroraAmazonAuroraInstanceAlternateCard', 'Amazon Aurora Amazon Aurora Instance Alternate Card', 'an optional description')
@enduml
```

## AmazonAuroraAmazonAuroraInstanceAlternateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonAuroraInstanceAlternateGroup
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')

' renders the element
AmazonAuroraAmazonAuroraInstanceAlternateGroup('AmazonAuroraAmazonAuroraInstanceAlternateGroup', 'Amazon Aurora Amazon Aurora Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonAuroraInstanceAlternateGroup
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')

' renders the element
AmazonAuroraAmazonAuroraInstanceAlternateGroup('AmazonAuroraAmazonAuroraInstanceAlternateGroup', 'Amazon Aurora Amazon Aurora Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate.md <==
# AmazonAuroraAmazonAuroraInstanceAlternate


```text
aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate
```

```text
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')
```



| Illustration | AmazonAuroraAmazonAuroraInstanceAlternate | AmazonAuroraAmazonAuroraInstanceAlternateCard | AmazonAuroraAmazonAuroraInstanceAlternateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate.png) | ![illustration for AmazonAuroraAmazonAuroraInstanceAlternate](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate.Local.png) | ![illustration for AmazonAuroraAmazonAuroraInstanceAlternateCard](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternateCard.Local.png) | ![illustration for AmazonAuroraAmazonAuroraInstanceAlternateGroup](../../../aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternateGroup.Local.png) |




## AmazonAuroraAmazonAuroraInstanceAlternate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonAuroraInstanceAlternate
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')

' renders the element
AmazonAuroraAmazonAuroraInstanceAlternate('AmazonAuroraAmazonAuroraInstanceAlternate', 'Amazon Aurora Amazon Aurora Instance Alternate', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonAuroraInstanceAlternate
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')

' renders the element
AmazonAuroraAmazonAuroraInstanceAlternate('AmazonAuroraAmazonAuroraInstanceAlternate', 'Amazon Aurora Amazon Aurora Instance Alternate', 'an optional tech label')
@enduml
```

## AmazonAuroraAmazonAuroraInstanceAlternateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonAuroraInstanceAlternateCard
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')

' renders the element
AmazonAuroraAmazonAuroraInstanceAlternateCard('AmazonAuroraAmazonAuroraInstanceAlternateCard', 'Amazon Aurora Amazon Aurora Instance Alternate Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonAuroraInstanceAlternateCard
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')

' renders the element
AmazonAuroraAmazonAuroraInstanceAlternateCard('AmazonAuroraAmazonAuroraInstanceAlternateCard', 'Amazon Aurora Amazon Aurora Instance Alternate Card', 'an optional description')
@enduml
```

## AmazonAuroraAmazonAuroraInstanceAlternateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonAuroraInstanceAlternateGroup
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')

' renders the element
AmazonAuroraAmazonAuroraInstanceAlternateGroup('AmazonAuroraAmazonAuroraInstanceAlternateGroup', 'Amazon Aurora Amazon Aurora Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonAuroraAmazonAuroraInstanceAlternateGroup
include('aws-20210730/Resource/Database/AmazonAuroraAmazonAuroraInstanceAlternate')

' renders the element
AmazonAuroraAmazonAuroraInstanceAlternateGroup('AmazonAuroraAmazonAuroraInstanceAlternateGroup', 'Amazon Aurora Amazon Aurora Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
